pm4py.algo.discovery.log\_skeleton.variants package
===================================================

Submodules
----------

pm4py.algo.discovery.log\_skeleton.variants.classic module
----------------------------------------------------------

.. automodule:: pm4py.algo.discovery.log_skeleton.variants.classic
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.log_skeleton.variants
   :members:
   :undoc-members:
   :show-inheritance:
